netapp_ontap.models.cluster_peer_remote API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.cluster_peer_remote`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ClusterPeerRemoteSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ClusterPeerRemote object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `ip_addresses: List[str] GET POST PATCH`

    The IPv4 addresses, IPv6 addresses, or hostnames of the peers.

  `name: str GET`

    The name of the remote cluster.

    Example: cluster2

  `serial_number: str GET`

    The serial number of the remote cluster.

    Example: 4048820-60-9